# gpyt

Interact with GPT on the command line.



### Desired Features
* `copy` to copy GPT's response to clipboard
* color coded responses
* add gpt jailbreaks
* `new` to start a new chat (clear all history and console window)
* store chat logs somewhere.
* add special flags like -t (terse) or -v (verbose) or -d (detailed) or -i (informal) or -f (for file input)
* scrolling text (adjustable speed, or disable all together)
